@@ -1,10 +1,11 @@
 #
-#  Copyright © 2020 Ingram Micro Inc. All rights reserved.
+#  Copyright © 2021 Ingram Micro Inc. All rights reserved.
 #
 
-from dj_rql.drf.backend import FilterCache, RQLFilterBackend
-from dj_rql.drf.paginations import RQLLimitOffsetPagination, RQLContentRangeLimitOffsetPagination
 from dj_rql.drf._utils import get_query
+from dj_rql.drf.backend import FilterCache, RQLFilterBackend
+from dj_rql.drf.paginations import RQLContentRangeLimitOffsetPagination, RQLLimitOffsetPagination
+
 
 __all__ = [
     'get_query',
