@@ -25,6 +25,7 @@ from dj_rql.constants import (
     SUPPORTED_FIELD_TYPES,
     SearchOperators,
 )
+from dj_rql.drf.fields import SelectField
 from dj_rql.exceptions import RQLFilterLookupError, RQLFilterParsingError, RQLFilterValueError
 from dj_rql.openapi import RQLFilterClassSpecification
 from dj_rql.parser import RQLParser
@@ -266,8 +267,23 @@ class RQLFilterClass:
         filter_lookup = self._get_filter_lookup(
             filter_name, operator, str_value, available_lookups, null_values,
         )
+        django_field = base_item.get('field')
+        if django_field and isinstance(django_field, SelectField):
+            raise RQLFilterLookupError(**self._get_error_details(
+                filter_name, filter_lookup, str_value,
+            ))
+
         django_lookup = self._get_django_lookup(filter_lookup, str_value, null_values)
 
+        use_repr = base_item.get('use_repr', False)
+
+        typed_value = None
+        if django_field is not None:
+            typed_value = self._get_typed_value(
+                filter_name, filter_lookup, str_value, django_field,
+                use_repr, null_values, django_lookup,
+            )
+
         if base_item.get('custom'):
             return self.build_q_for_custom_filter(FilterArgs(
                 filter_name,
@@ -278,14 +294,6 @@ class RQLFilterClass:
                 django_lookup=django_lookup,
             ))
 
-        django_field = base_item['field']
-        use_repr = base_item.get('use_repr', False)
-
-        typed_value = self._get_typed_value(
-            filter_name, filter_lookup, str_value, django_field,
-            use_repr, null_values, django_lookup,
-        )
-
         if not isinstance(filter_item, iterable_types):
             return self._build_django_q(filter_item, django_lookup, filter_lookup, typed_value)
 
